<?php

declare(strict_types=1);

namespace db;

use db\DataSource;
use models\CampGroundSchema;

class CampGroundQuery
{
    public static function findByIdAndDelete($id)
    {
        try {
            $success = false;
            $db = new DataSource;
            $db->begin();

            if (!ImageQuery::findByCampIdAndDelete($id)) return false;
            if (!ReviewQuery::findByCampIdAndDelete($id)) return false;
            $sql = 'delete from campgrounds where id = :id;';
            $success= $db->execute($sql, [':id' => $id]);

            return $success;

        } finally {
            if ($success)
                $db->commit();
            else
                $db->rollback();
        }
        return false;
    }

    public static function update(CampGroundSchema $campground)
    {
        try {
            $success = false;
            $db = new DataSource;
            $db->begin();
            $sql = 'update campgrounds set title = :title, price = :price, description = :description, location = :location, author = :author, geometry = :geometry where id = :id';

            $result = $db->execute($sql, [
                ':title' => $campground->title,
                ':price' => $campground->price,
                ':description' => $campground->description,
                ':location' => $campground->location,
                ':author' => $campground->author,
                ':geometry' => $campground->geometry,
                ':id' => $campground->id,
            ]);
            if (!$result) return null;
            if (!ImageQuery::save($campground->id, $campground->images, exclude_exist: true)) return null;
            if (!ImageQuery::deleteImages($campground->id, $campground->deleteImages)) return null;

            $success = true;

            return $campground;
        } finally {
            if ($success)
                $db->commit();
            else
                $db->rollback();
        }
        return null;
    }

    public static function save(CampGroundSchema $campground)
    {
        try {
            $success = false;
            $db = new DataSource;
            $db->begin();
            if (!self::insert($campground)) return null;
            $id = $db->lastInsertId();
            $campground->id = intval($id);
            ImageQuery::save($campground->id, $campground->images);

            $success = true;

            return $campground;
        } finally {
            if ($success)
                $db->commit();
            else
                $db->rollback();
        }
        return null;
    }

    private static function insert(CampGroundSchema $campground)
    {
        $db = new DataSource;
        $sql = 'insert into campgrounds (title, price, description, location, author, geometry) values (:title, :price, :description, :location, :author, :geometry)';

        return $db->execute($sql, [
            ':title' => $campground->title,
            ':price' => $campground->price,
            ':description' => $campground->description,
            ':location' => $campground->location,
            ':author' => $campground->author,
            ':geometry' => $campground->geometry,
        ]);
    }

    public static function deleteAll()
    {
        $db  = new DataSource;
        $sql = 'delete from campgrounds';

        return $db->execute($sql);
    }

    public static function select(string $criteria = null)
    {
        $db = new DataSource;
        $sql = 'select * from campgrounds ' . (empty($criteria) ? '' : " where {$criteria}");
        $result = $db->select($sql, [], DataSource::CLS, CampGroundSchema::class);
        if (!empty($result)) {
            foreach ($result as $camp)
                $camp->images = ImageQuery::select("camp_id = {$camp->id}");
        }

        return $result;
    }

    public static function findById($id)
    {
        $db = new DataSource;
        $sql = 'select * from campgrounds where id = :id';
        $result = $db->select($sql, [':id' => $id,], DataSource::CLS, CampGroundSchema::class);
        if (empty($result) || count($result) === 0) return null;
        $camp = $result[0];
        $camp->images = ImageQuery::select("camp_id = {$camp->id}");
        return $camp;
    }
}
