<?php

declare(strict_types=1);

namespace middleware;

use Throwable;
use utils\Flush;
use utils\ReturnTo;
use models\UserSchema;
use models\ReviewSchema;
use models\CampGroundSchema;

function currentUser()
{
    return UserSchema::getSession();
}

function isLoggedIn()
{
    $user = UserSchema::getSession();

    if (!isset($user)) {
        ReturnTo::push(CURRENT_PATH);
        Flush::push(Flush::ERROR, 'ログインしてください');
        redirect('/login');
    }

    return $user;
}

function isAuthor(CampGroundSchema $campground, UserSchema|null $user)
{
    if (!empty($campground) && !$campground->isOwner($user)) {
        ReturnTo::clearSession();
        Flush::push(Flush::ERROR, 'そのアクションの権限がありません');
        redirect("/campgrounds/{$campground->id}");
    }
}

function isReviewAuthor(CampGroundSchema $campground, ReviewSchema $review, UserSchema|null $user)
{
    if (!empty($campground) && !empty($review) && !$review->isOwner($user)) {
        ReturnTo::clearSession();
        Flush::push(Flush::ERROR, 'そのアクションの権限がありません');
        redirect("/campgrounds/{$campground->id}");
    }
}
